@@ -104,7 +104,7 @@ class KubeModel(ABC):
         """
         optimizer = self.configure_optimizers()
         self.optimizer = optimizer
-        self._load_optimizer_state()
+        self._load_optimizer_redis()
   
         # TODO here the state loaded should be the averaged one not the saved from earlier
 
@@ -227,6 +227,8 @@ class KubeModel(ABC):
         self._set_device()
         self._network.train()
         self._config_optimizer()
+        self.__load_model()
+        self._load_optimizer_redis()
 
     def _on_train_end(self):
         """
@@ -234,8 +236,9 @@ class KubeModel(ABC):
         :return:
         """
         #self.__save_model()
-        
-        pass
+        self.__save_model()
+        self._save_optimizer_redis()
+        #pass
         # self._save_optimizer_state()
 
     def _on_iteration_start(self):
@@ -247,7 +250,7 @@ class KubeModel(ABC):
         :return:
         """
         self.__load_model()
-        self._load_optimizer_state()
+        self._load_optimizer_redis()
         #self._reset_optimizer_state()
 
     def _on_iteration_end(self):
@@ -256,7 +259,7 @@ class KubeModel(ABC):
         :return:
         """
         self.__save_model()
-        self._save_optimizer_state()
+        self._save_optimizer_redis()
 
 
     def _batch_to_device(self, batch: Union[torch.Tensor, Iterable[torch.Tensor]]):
@@ -322,7 +325,7 @@ class KubeModel(ABC):
 
             # load the reference model, train and save
             try:
-                self._on_iteration_start()
+                #self._on_iteration_start()
 
                 for idx, batch in enumerate(loader):
                     # send the batch to the appropriate device
@@ -330,7 +333,7 @@ class KubeModel(ABC):
                     loss += self.train(batch, idx)
                     self.logger.debug(f'loss is {loss}, iterations are {num_iterations}')
 
-                self._on_iteration_end()
+                #self._on_iteration_end()
             except RedisError as re:
                 raise StorageError(re)
             finally:
